#
# Hexahedrization of the geometry generated by the Python script
# SMESH_fixation.py
# Hypothesis and algorithms for the mesh generation are global
#

import SMESH_fixation
import SMESH
import smeshpy

compshell = SMESH_fixation.compshell
idcomp = SMESH_fixation.idcomp
geompy = SMESH_fixation.geompy
salome = SMESH_fixation.salome
sg = SMESH_fixation.sg

ShapeTypeShell     = 3
ShapeTypeFace      = 4
ShapeTypeEdge      = 6

print "Analysis of the geometry to be meshed :"
subShellList=geompy.SubShapeAll(compshell,ShapeTypeShell)
subFaceList=geompy.SubShapeAll(compshell,ShapeTypeFace)
subEdgeList=geompy.SubShapeAll(compshell,ShapeTypeEdge)

print "number of Shells in compshell : ",len(subShellList)
print "number of Faces in compshell : ",len(subFaceList)
print "number of Edges in compshell : ",len(subEdgeList)

status=geompy.CheckShape(compshell)
print " check status ", status

### ---- launch SMESH

smeshgui = salome.ImportComponentGUI("SMESH")
smeshgui.Init(salome.myStudyId)

gen=smeshpy.smeshpy()

### ---- create Hypothesis

print "-------------------------- create Hypothesis"

print "-------------------------- NumberOfSegments"

numberOfSegments = 5

hyp1=gen.CreateHypothesis("NumberOfSegments")
hypNbSeg=hyp1._narrow(SMESH.SMESH_NumberOfSegments)
hypNbSeg.SetNumberOfSegments(numberOfSegments)
hypNbSegID = hypNbSeg.GetId()
print hypNbSeg.GetName()
print hypNbSegID
print hypNbSeg.GetNumberOfSegments()

idseg = smeshgui.AddNewHypothesis( salome.orb.object_to_string(hypNbSeg) )
smeshgui.SetName(idseg, "NumberOfSegments")

# ---- create Algorithms

print "-------------------------- create Algorithms"

print "-------------------------- Regular_1D"

hypothesis=gen.CreateHypothesis("Regular_1D")
regular1D = hypothesis._narrow(SMESH.SMESH_Regular_1D)
regularID = smeshgui.AddNewAlgorithms( salome.orb.object_to_string(regular1D) )
smeshgui.SetName(regularID, "Wire Discretisation")

print "-------------------------- Quadrangle_2D"

hypothesis=gen.CreateHypothesis("Quadrangle_2D")
quad2D = hypothesis._narrow(SMESH.SMESH_Quadrangle_2D)
quadID = smeshgui.AddNewAlgorithms( salome.orb.object_to_string(quad2D) )
smeshgui.SetName(quadID, "Quadrangle_2D")

print "-------------------------- Hexa_3D"

hypothesis=gen.CreateHypothesis("Hexa_3D")
hexa3D = hypothesis._narrow(SMESH.SMESH_Hexa_3D)
hexaID = smeshgui.AddNewAlgorithms( salome.orb.object_to_string(hexa3D) )
smeshgui.SetName(hexaID, "Hexa_3D")

# ---- init a Mesh with the compshell

mesh=gen.Init(idcomp)
idmesh = smeshgui.AddNewMesh( salome.orb.object_to_string(mesh) )
smeshgui.SetName(idmesh, "MeshcompShel")
smeshgui.SetShape(idcomp, idmesh)

# ---- add hypothesis to compshell

print "-------------------------- add hypothesis to compshell"

ret=mesh.AddHypothesis(compshell,regular1D)
print ret
ret=mesh.AddHypothesis(compshell,hypNbSeg)
print ret
ret=mesh.AddHypothesis(compshell,quad2D)
print ret
ret=mesh.AddHypothesis(compshell,hexa3D)
print ret

smeshgui.SetAlgorithms( idmesh, regularID)
smeshgui.SetHypothesis( idmesh, idseg )
smeshgui.SetAlgorithms( idmesh, quadID )
smeshgui.SetAlgorithms( idmesh, hexaID )

sg.updateObjBrowser(1)


print "-------------------------- compute compshell"
ret=gen.Compute(mesh,idcomp)
print ret
if ret != 0:
    log=mesh.GetLog(0) # no erase trace
    for linelog in log:
        print linelog
else:
    print "problem when Computing the mesh"

sg.updateObjBrowser(1)
